var NAVTREE =
[
  [ "Qore SoapClient Module Reference", "index.html", [
    [ "SoapClient Module", "index.html", [
      [ "Introduction to the SoapClient Module", "index.html#soapclientintro", null ],
      [ "Example", "index.html#Example", null ],
      [ "SoapClient Release Notes", "index.html#soapclientrelnotes", [
        [ "SoapClient v0.2.5", "index.html#soapclient_0_2_5", null ],
        [ "SoapClient v0.2.4.1", "index.html#soapclient_0_2_4_1", null ],
        [ "SoapClient v0.2.4", "index.html#soapclient_0_2_4", null ],
        [ "SoapClient v0.2.3", "index.html#soapclient_0_2_3", null ]
      ] ]
    ] ],
    [ "Namespaces", null, [
      [ "Namespace List", "namespaces.html", "namespaces" ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';